import { world } from "@minecraft/server";
(function CobblestoneGolem () {
    const CONFIG = {
        triggerBlocks: ["minecraft:lit_pumpkin", "minecraft:carved_pumpkin"],
        targetBlocks: ["minecraft:chiseled_stone_bricks"],
        targetBlocks2: ["minecraft:stone"],
        entityToSpawn: "golems:cobblestone_golem",
        spawnEvent: "minecraft:from_player"
    };
    function isTargetBlock(block, targetBlocks) {
        return block && targetBlocks.includes(block.typeId);
    }
    function destroyBlock(block, dimension) {
        if (block) {
            const location = block.location;
            dimension.runCommand(`setblock ${location.x} ${location.y} ${location.z} air destroy`);
            dimension.runCommand(`kill @e[type=item,x=${location.x},y=${location.y},z=${location.z},dx=0,dy=0,dz=0]`);
        }
    }
    function spawnEntity(entityType, location, dimension, spawnEvent) {
        const entity = dimension.spawnEntity(entityType, location);
        if (entity) {
            entity.triggerEvent(spawnEvent);
        }
    }
    world.afterEvents.playerPlaceBlock.subscribe(e => {
        if (!CONFIG.triggerBlocks.includes(e.block.typeId)) return;
        let center_block = e.block.below();
        if (!center_block) return;

        let center = isTargetBlock(center_block, CONFIG.targetBlocks);
        let east = isTargetBlock(center_block.east(), CONFIG.targetBlocks2);
        let west = isTargetBlock(center_block.west(), CONFIG.targetBlocks2);
        let north = isTargetBlock(center_block.north(), CONFIG.targetBlocks2);
        let south = isTargetBlock(center_block.south(), CONFIG.targetBlocks2);

        if (center) {
            if(east && west){
            destroyBlock(center_block.east(), e.dimension);
            destroyBlock(center_block.west(), e.dimension);
            destroyBlock(center_block.above(), e.dimension);
            destroyBlock(center_block, e.dimension);
            spawnEntity(CONFIG.entityToSpawn, center_block.location, e.dimension, CONFIG.spawnEvent);
            }else if(north && south){
                destroyBlock(center_block.north(), e.dimension);
                destroyBlock(center_block.south(), e.dimension);
                destroyBlock(center_block.above(), e.dimension);
                destroyBlock(center_block, e.dimension);
                spawnEntity(CONFIG.entityToSpawn, center_block.location, e.dimension, CONFIG.spawnEvent);
            }
        }
    });
})();
(function PlankGolem(){
    const CONFIG = {
        triggerBlocks: ["minecraft:lit_pumpkin", "minecraft:carved_pumpkin"], // Lista de bloques desencadenantes
        targetBlocks: ["minecraft:oak_planks","minecraft:dark_oak_planks","minecraft:birch_planks","minecraft:acacia_planks","minecraft:jungle_planks","minecraft:spruce_planks","minecraft:mangrove_planks","minecraft:cherry_planks","minecraft:bamboo_planks"], // Lista de bloques objetivo
        entityToSpawn: "golems:plank_golem",
        spawnEvent: "minecraft:from_player"
    };
    function isTargetBlock(block, targetBlocks) {
        return block && targetBlocks.includes(block.typeId);
    }
    function destroyBlock(block, dimension) {
        if (block) {
            const location = block.location;
            dimension.runCommand(`setblock ${location.x} ${location.y} ${location.z} air destroy`);
            dimension.runCommand(`kill @e[type=item,x=${location.x},y=${location.y},z=${location.z},dx=0,dy=0,dz=0]`);
        }
    }
    function spawnEntity(entityType, location, dimension, spawnEvent) {
        const entity = dimension.spawnEntity(entityType, location);
        if (entity) {
            entity.triggerEvent(spawnEvent);
        }
    }
    world.afterEvents.playerPlaceBlock.subscribe(e => {
        if (!CONFIG.triggerBlocks.includes(e.block.typeId)) return;
        
        let center_block = e.block.below();
        if (!center_block) return;
        
        let center = isTargetBlock(center_block, "minecraft:target");
        let below = isTargetBlock(center_block.below(), CONFIG.targetBlocks);
        
        if (center && below) {
            destroyBlock(center_block.above(), e.dimension);
            destroyBlock(center_block, e.dimension);
            destroyBlock(center_block.below(), e.dimension);
            spawnEntity(CONFIG.entityToSpawn, center_block.below().location, e.dimension, CONFIG.spawnEvent);
        }
    });
})();